export type Rule = {
	isAlpha?: RuleOption
	isEmail?: RuleOption
	isEmpty?: RuleOption
	isLength?: RuleOption
	isNumeric?: RuleOption
}

type RuleOption = {
	need: Boolean
	message: String
	min?: Number
	max?: Number
}

class Validator {
	public rules?: Rule
	public value?: Object
	public errors: String[] = []

	constructor() {
		this.rules = undefined
		this.value = undefined
	}

	validate = (val: String | Number, rules: Rule): Boolean => {
		this.rules = rules
		for (let key in this.rules) {
			const r = require('./rules/' + key)(val, rules)
			if (r != this.rules[key as keyof Rule]?.need) {
				this.errors.push(this.rules[key as keyof Rule]?.message as String)
			}
		}
		return true
	}

	success = (): Boolean => {
		return this.errors.length == 0
	}

	getErrors = (): String[] => {
		return this.errors
	}

	getLastError = (): String => {
		return this.errors[this.errors.length - 1]
	}
}

export default Validator
